diff -pruN 2.0.0-4/build_and_test.sh 2.1.0-1/build_and_test.sh
--- 2.0.0-4/build_and_test.sh	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/build_and_test.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-#!/usr/bin/bash
-
-BUILD_TYPE=$1
-
-rm -rf objdir
-mkdir objdir
-cd objdir
-cmake .. -DCMAKE_BUILD_TYPE=$BUILD_TYPE
-make -j`nproc` VERBOSE=1
-
-if [ "$BUILD_TYPE" = "COVERAGE" ]; then
-pytest --cov=./
-CODECOV_TOKEN="7c181327-be77-41de-aa6e-ca7187b14376" codecov
-else
-pytest
-fi
diff -pruN 2.0.0-4/clang_delta/RemoveUnusedFunction.cpp 2.1.0-1/clang_delta/RemoveUnusedFunction.cpp
--- 2.0.0-4/clang_delta/RemoveUnusedFunction.cpp	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/clang_delta/RemoveUnusedFunction.cpp	2021-01-11 10:52:13.000000000 +0000
@@ -643,7 +643,13 @@ void RemoveUnusedFunction::removeOneFunc
     const FunctionDecl *ParentFD = UsingParentFDs[(*I).first];
     if (ParentFD && RemovedFDs.count(ParentFD->getCanonicalDecl()))
       continue;
-    RewriteHelper->removeDecl((*I).first);
+    const UsingDecl *UD = (*I).first;
+    SourceRange Range = UD->getSourceRange();
+    if (Range.getBegin().isMacroID()) {
+      TheRewriter.RemoveText(SrcManager->getExpansionRange(Range));
+    } else {
+      RewriteHelper->removeDecl((*I).first);
+    }
   }
 }
 
diff -pruN 2.0.0-4/clang_delta/RewriteUtils.cpp 2.1.0-1/clang_delta/RewriteUtils.cpp
--- 2.0.0-4/clang_delta/RewriteUtils.cpp	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/clang_delta/RewriteUtils.cpp	2021-01-11 10:52:13.000000000 +0000
@@ -736,9 +736,15 @@ std::string RewriteUtils::getStmtIndentS
   StringRef MB = SrcManager->getBufferData(FID);
  
   unsigned lineNo = SrcManager->getLineNumber(FID, StartOffset) - 1;
+#if LLVM_VERSION_MAJOR >= 12
+  const SrcMgr::ContentCache&
+      Content = SrcManager->getSLocEntry(FID).getFile().getContentCache();
+  unsigned lineOffs = Content.SourceLineCache[lineNo];
+#else
   const SrcMgr::ContentCache *
       Content = SrcManager->getSLocEntry(FID).getFile().getContentCache();
   unsigned lineOffs = Content->SourceLineCache[lineNo];
+#endif
  
   // Find the whitespace at the start of the line.
   StringRef indentSpace;
diff -pruN 2.0.0-4/clang_delta/Transformation.cpp 2.1.0-1/clang_delta/Transformation.cpp
--- 2.0.0-4/clang_delta/Transformation.cpp	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/clang_delta/Transformation.cpp	2021-01-11 10:52:13.000000000 +0000
@@ -108,7 +108,12 @@ void Transformation::outputTransformedSo
 void Transformation::outputOriginalSource(llvm::raw_ostream &OutStream)
 {
   FileID MainFileID = SrcManager->getMainFileID();
+#if LLVM_VERSION_MAJOR >= 12
+  llvm::Optional<llvm::MemoryBufferRef> MainBuf =
+      SrcManager->getBufferOrNone(MainFileID);
+#else
   const llvm::MemoryBuffer *MainBuf = SrcManager->getBuffer(MainFileID);
+#endif
   TransAssert(MainBuf && "Empty MainBuf!");
   OutStream << MainBuf->getBufferStart();
   OutStream.flush();
diff -pruN 2.0.0-4/CMakeLists.txt 2.1.0-1/CMakeLists.txt
--- 2.0.0-4/CMakeLists.txt	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/CMakeLists.txt	2021-01-11 10:52:13.000000000 +0000
@@ -88,7 +88,7 @@ endif()
 # `git archive' inserts the abbreviated hash of the archive's commit into this
 # file.  (See the `.gitattributes' file.)
 #
-set(GIT_HASH "cfdc482")
+set(GIT_HASH "972f4ba")
 if(GIT_HASH MATCHES "^\\$")
   ## METHOD 2: The source tree is a git repository.
   get_git_head_revision(GIT_REFSPEC GIT_HASH)
@@ -122,11 +122,11 @@ check_include_file("unistd.h"		HAVE_UNIS
 set(cvise_PACKAGE             "cvise")
 set(cvise_PACKAGE_BUGREPORT   "https://github.com/marxin/cvise/issues")
 set(cvise_PACKAGE_NAME        "cvise")
-set(cvise_PACKAGE_STRING      "cvise 2.0.0")
+set(cvise_PACKAGE_STRING      "cvise 2.1.0")
 set(cvise_PACKAGE_TARNAME     "cvise")
 set(cvise_PACKAGE_URL         "https://github.com/marxin/cvise/")
-set(cvise_PACKAGE_VERSION     "2.0.0")
-set(cvise_VERSION             "2.0.0")
+set(cvise_PACKAGE_VERSION     "2.1.0")
+set(cvise_VERSION             "2.1.0")
 set(cvise_LLVM_VERSION        "${LLVM_PACKAGE_VERSION}")
 
 configure_file("cmake_config.h.in" "${PROJECT_BINARY_DIR}/config.h")
diff -pruN 2.0.0-4/codecov.yml 2.1.0-1/codecov.yml
--- 2.0.0-4/codecov.yml	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/codecov.yml	2021-01-11 10:52:13.000000000 +0000
@@ -2,11 +2,11 @@ codecov:
   disable_default_path_fixes: no
 
 fixes:
-  - "/usr/src/cvise/objdir/usr/src/cvise/objdir::"
-  - "/usr/src/cvise/objdir/usr/src/cvise::"
+  - "/__w/cvise/cvise/objdir::"
+  - "/__w/cvise/cvise/::"
 ignore:
   - "**/include"
   - "cvise/tests"
-  - "/usr/src/cvise/objdir/delta/topformflat.c"
-  - "/usr/src/cvise/objdir/clex/strlex.c"
-  - "/usr/src/cvise/objdir/clex/clex.c"
+  - "/__w/cvise/cvise/objdir/delta/topformflat.c"
+  - "/__w/cvise/cvise/objdir/clex/strlex.c"
+  - "/__w/cvise/cvise/objdir/clex/clex.c"
diff -pruN 2.0.0-4/cvise/cvise.py 2.1.0-1/cvise/cvise.py
--- 2.0.0-4/cvise/cvise.py	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/cvise/cvise.py	2021-01-11 10:52:13.000000000 +0000
@@ -122,7 +122,7 @@ class CVise:
 
         return pass_group
 
-    def reduce(self, pass_group, skip_initial=False):
+    def reduce(self, pass_group, skip_initial):
         self._check_prerequisites(pass_group)
         self.test_manager.check_sanity(True)
 
diff -pruN 2.0.0-4/cvise/passes/clangbinarysearch.py 2.1.0-1/cvise/passes/clangbinarysearch.py
--- 2.0.0-4/cvise/passes/clangbinarysearch.py	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/cvise/passes/clangbinarysearch.py	2021-01-11 10:52:13.000000000 +0000
@@ -51,9 +51,13 @@ class ClangBinarySearchPass(AbstractPass
 
         try:
             proc = subprocess.run(cmd, universal_newlines=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        except subprocess.SubprocessError:
+        except subprocess.SubprocessError as e:
+            logging.warning(f'clang_delta --query-instances failed: {e}')
             return 0
 
+        if proc.returncode != 0:
+            logging.warning(f'clang_delta --query-instances failed with exit code {proc.returncode}: {proc.stderr.strip()}')
+
         m = re.match('Available transformation instances: ([0-9]+)$', proc.stdout)
 
         if m is None:
diff -pruN 2.0.0-4/cvise/passes/lines.py 2.1.0-1/cvise/passes/lines.py
--- 2.0.0-4/cvise/passes/lines.py	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/cvise/passes/lines.py	2021-01-11 10:52:13.000000000 +0000
@@ -34,6 +34,7 @@ class LinesPass(AbstractPass):
             try:
                 check_sanity()
             except InsaneTestCaseError:
+
                 shutil.move(backup.name, test_case)
                 # if we are not the first lines pass, we should bail out
                 if self.arg != '0':
@@ -52,7 +53,7 @@ class LinesPass(AbstractPass):
         if self.arg != 'None':
             self.__format(test_case, check_sanity)
             if self.bailout:
-                logging.info('Skipping pass as sanity check fails for topformflat output')
+                logging.warning('Skipping pass as sanity check fails for topformflat output')
                 return None
         instances = self.__count_instances(test_case)
         return BinaryState.create(instances)
diff -pruN 2.0.0-4/cvise/utils/testing.py 2.1.0-1/cvise/utils/testing.py
--- 2.0.0-4/cvise/utils/testing.py	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/cvise/utils/testing.py	2021-01-11 10:52:13.000000000 +0000
@@ -130,12 +130,13 @@ class TestManager:
 
     def __init__(self, pass_statistic, test_script, timeout, save_temps, test_cases, parallel_tests,
                  no_cache, skip_key_off, silent_pass_bug, die_on_pass_bug, print_diff, max_improvement,
-                 no_give_up, also_interesting):
+                 no_give_up, also_interesting, start_with_pass):
         self.test_script = os.path.abspath(test_script)
         self.timeout = timeout
         self.save_temps = save_temps
         self.pass_statistic = pass_statistic
         self.test_cases = set()
+        self.test_cases_modes = {}
         self.parallel_tests = parallel_tests
         self.no_cache = no_cache
         self.skip_key_off = skip_key_off
@@ -145,10 +146,13 @@ class TestManager:
         self.max_improvement = max_improvement
         self.no_give_up = no_give_up
         self.also_interesting = also_interesting
+        self.start_with_pass = start_with_pass
 
         for test_case in test_cases:
             self.check_file_permissions(test_case, [os.F_OK, os.R_OK, os.W_OK], InvalidTestCaseError)
-            self.test_cases.add(os.path.abspath(test_case))
+            fullpath = os.path.abspath(test_case)
+            self.test_cases.add(fullpath)
+            self.test_cases_modes[fullpath] = os.stat(fullpath).st_mode
 
         self.orig_total_file_size = self.total_file_size
         self.cache = {}
@@ -165,6 +169,10 @@ class TestManager:
         if not self.save_temps:
             rmfolder(self.root)
 
+    def restore_mode(self):
+        for test_case in self.test_cases:
+            os.chmod(test_case, self.test_cases_modes[test_case])
+
     @classmethod
     def is_valid_test(cls, test_script):
         for mode in {os.F_OK, os.X_OK}:
@@ -193,7 +201,7 @@ class TestManager:
         lines = 0
         for file in files:
             with open(file) as f:
-                lines += len(f.readlines())
+                lines += len([line for line in f.readlines() if line and not line.isspace()])
         return lines
 
     def backup_test_cases(self):
@@ -441,6 +449,12 @@ class TestManager:
                     self.state = state
 
     def run_pass(self, pass_):
+        if self.start_with_pass:
+            if self.start_with_pass == str(pass_):
+                self.start_with_pass = None
+            else:
+                return
+
         self.current_pass = pass_
         self.futures = []
         self.temporary_folders = {}
@@ -509,6 +523,7 @@ class TestManager:
 
                     self.cache[pass_key][test_case_before_pass] = tmp_file.read()
 
+        self.restore_mode()
         self.remove_root()
         self.pass_statistic.stop(self.current_pass)
 
diff -pruN 2.0.0-4/cvise-delta.py 2.1.0-1/cvise-delta.py
--- 2.0.0-4/cvise-delta.py	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/cvise-delta.py	2021-01-11 10:52:13.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/env python3
 
 import subprocess
 import sys
diff -pruN 2.0.0-4/cvise.py 2.1.0-1/cvise.py
--- 2.0.0-4/cvise.py	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/cvise.py	2021-01-11 10:52:13.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#!/usr/bin/env python3
 
 import argparse
 import datetime
@@ -167,6 +167,7 @@ if __name__ == '__main__':
     parser.add_argument('--save-temps', action='store_true', default=False, help="Don't delete /tmp/cvise-xxxxxx directories on termination")
     parser.add_argument('--skip-initial-passes', action='store_true', default=False, help='Skip initial passes (useful if input is already partially reduced)')
     parser.add_argument('--remove-pass', help='Remove all instances of the specified passes from the schedule (comma-separated)')
+    parser.add_argument('--start-with-pass', help='Start with the specified pass')
     parser.add_argument('--no-timing', action='store_true', default=False, help='Do not print timestamps about reduction progress')
     parser.add_argument('--timestamp', action='store_true', default=False, help='Print timestamps instead of relative time from a reduction start')
     parser.add_argument('--timeout', type=int, nargs='?', default=300, help='Interestingness test timeout in seconds')
@@ -260,7 +261,7 @@ if __name__ == '__main__':
     script = None
     if args.commands:
         with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.sh') as script:
-            script.write('#!/usr/bin/bash\n\n')
+            script.write('#!/bin/bash\n\n')
             script.write(args.commands + '\n')
         os.chmod(script.name, 0o744)
         logging.info('Using temporary interestingness test: %s' % script.name)
@@ -268,7 +269,8 @@ if __name__ == '__main__':
 
     test_manager = testing.TestManager(pass_statistic, args.interestingness_test, args.timeout,
                                        args.save_temps, args.test_cases, args.n, args.no_cache, args.skip_key_off, args.shaddap,
-                                       args.die_on_pass_bug, args.print_diff, args.max_improvement, args.no_give_up, args.also_interesting)
+                                       args.die_on_pass_bug, args.print_diff, args.max_improvement, args.no_give_up, args.also_interesting,
+                                       args.start_with_pass)
 
     reducer = CVise(test_manager)
 
diff -pruN 2.0.0-4/debian/changelog 2.1.0-1/debian/changelog
--- 2.0.0-4/debian/changelog	2021-01-08 13:02:42.000000000 +0000
+++ 2.1.0-1/debian/changelog	2021-01-12 18:21:35.000000000 +0000
@@ -1,3 +1,9 @@
+cvise (2.1.0-1) unstable; urgency=medium
+
+  * New upstream version.
+
+ -- Matthias Klose <doko@debian.org>  Tue, 12 Jan 2021 19:21:35 +0100
+
 cvise (2.0.0-4) unstable; urgency=medium
 
   * Update to the branch 20210108.
diff -pruN 2.0.0-4/debian/cvise.1 2.1.0-1/debian/cvise.1
--- 2.0.0-4/debian/cvise.1	2021-01-08 13:02:42.000000000 +0000
+++ 2.1.0-1/debian/cvise.1	2021-01-12 18:21:35.000000000 +0000
@@ -1,5 +1,5 @@
 .\" DO NOT MODIFY THIS FILE!  It was generated by help2man 1.47.16.
-.TH CVISE "1" "January 2021" "cvise 2.0.0" "User Commands"
+.TH CVISE "1" "January 2021" "cvise 2.1.0" "User Commands"
 .SH NAME
 cvise \- super-parallel Python port of the C-Reduce project
 .SH DESCRIPTION
diff -pruN 2.0.0-4/debian/patches/git-updates.diff 2.1.0-1/debian/patches/git-updates.diff
--- 2.0.0-4/debian/patches/git-updates.diff	2021-01-08 13:01:29.000000000 +0000
+++ 2.1.0-1/debian/patches/git-updates.diff	2021-01-12 18:21:35.000000000 +0000
@@ -1,291 +1,2 @@
 git diff cfdc48293830e30782091b98e7da7316482f4c2c 1a9f47f5303705f3138816679d20c85d365d11d8
 
-diff --git a/.travis.yml b/.travis.yml
-index 77d89c3..465d372 100644
---- a/.travis.yml
-+++ b/.travis.yml
-@@ -27,6 +27,24 @@ addons:
- 
- matrix:
-   - include:
-+    - name: DEBUG build (LLVM 9)
-+      stage: build
-+      env:
-+        - BUILD_TYPE=DEBUG
-+        - DIST=opensusetw-llvm9
-+
-+    - name: DEBUG build (LLVM 10)
-+      stage: build
-+      env:
-+        - BUILD_TYPE=DEBUG
-+        - DIST=opensusetw-llvm10
-+
-+    - name: DEBUG build (LLVM 10)
-+      stage: build
-+      env:
-+        - BUILD_TYPE=DEBUG
-+        - DIST=opensusetw-llvm10
-+
-     - name: COVERAGE build (LLVM 11)
-       stage: build
-       env:
-@@ -39,6 +57,12 @@ matrix:
-         - BUILD_TYPE=UBSAN
-         - DIST=opensusetw-llvm11
- 
-+    - name: Leap 15 (LLVM 9)
-+      stage: build
-+      env:
-+        - BUILD_TYPE=DEBUG
-+        - DIST=opensuselp15-llvm9
-+
-     - name: ASAN build (LLVM 11)
-       stage: build
-       env:
-diff --git a/Docker/Dockerfile-opensuselp15-llvm9 b/Docker/Dockerfile-opensuselp15-llvm9
-new file mode 100644
-index 0000000..0b24656
---- /dev/null
-+++ b/Docker/Dockerfile-opensuselp15-llvm9
-@@ -0,0 +1,14 @@
-+FROM opensuse/leap
-+
-+RUN zypper -n install \
-+        binutils clang9-devel cmake flex gcc-c++ llvm9-devel python3-Pebble python3-pytest python3-psutil unifdef \
-+        python3-pytest-flake8 \
-+        python3-flake8 \
-+        python3-flake8-builtins \
-+        python3-flake8-bugbear \
-+        python3-flake8-import-order \
-+        python3-flake8-quotes
-+ENV LSAN_OPTIONS="detect_leaks=0"
-+
-+WORKDIR /usr/src/cvise
-+VOLUME /usr/src/cvise
-diff --git a/build_and_test.sh b/build_and_test.sh
-index 95c1539..b726dd4 100755
---- a/build_and_test.sh
-+++ b/build_and_test.sh
-@@ -1,4 +1,4 @@
--#!/usr/bin/bash
-+#!/bin/bash
- 
- BUILD_TYPE=$1
- 
-diff --git a/clang_delta/RemoveUnusedFunction.cpp b/clang_delta/RemoveUnusedFunction.cpp
-index 0c93298..4a66293 100644
---- a/clang_delta/RemoveUnusedFunction.cpp
-+++ b/clang_delta/RemoveUnusedFunction.cpp
-@@ -643,7 +643,13 @@ void RemoveUnusedFunction::removeOneFunctionDeclGroup(const FunctionDecl *FD)
-     const FunctionDecl *ParentFD = UsingParentFDs[(*I).first];
-     if (ParentFD && RemovedFDs.count(ParentFD->getCanonicalDecl()))
-       continue;
--    RewriteHelper->removeDecl((*I).first);
-+    const UsingDecl *UD = (*I).first;
-+    SourceRange Range = UD->getSourceRange();
-+    if (Range.getBegin().isMacroID()) {
-+      TheRewriter.RemoveText(SrcManager->getExpansionRange(Range));
-+    } else {
-+      RewriteHelper->removeDecl((*I).first);
-+    }
-   }
- }
- 
-diff --git a/cvise-delta.py b/cvise-delta.py
-index 5c1e1fd..ab57aa2 100755
---- a/cvise-delta.py
-+++ b/cvise-delta.py
-@@ -1,4 +1,4 @@
--#!/usr/bin/python3
-+#!/usr/bin/env python3
- 
- import subprocess
- import sys
-diff --git a/cvise.py b/cvise.py
-index 15efaf6..bf5d14d 100755
---- a/cvise.py
-+++ b/cvise.py
-@@ -1,4 +1,4 @@
--#!/usr/bin/python3
-+#!/usr/bin/env python3
- 
- import argparse
- import datetime
-@@ -167,6 +167,7 @@ if __name__ == '__main__':
-     parser.add_argument('--save-temps', action='store_true', default=False, help="Don't delete /tmp/cvise-xxxxxx directories on termination")
-     parser.add_argument('--skip-initial-passes', action='store_true', default=False, help='Skip initial passes (useful if input is already partially reduced)')
-     parser.add_argument('--remove-pass', help='Remove all instances of the specified passes from the schedule (comma-separated)')
-+    parser.add_argument('--start-with-pass', help='Start with the specified pass')
-     parser.add_argument('--no-timing', action='store_true', default=False, help='Do not print timestamps about reduction progress')
-     parser.add_argument('--timestamp', action='store_true', default=False, help='Print timestamps instead of relative time from a reduction start')
-     parser.add_argument('--timeout', type=int, nargs='?', default=300, help='Interestingness test timeout in seconds')
-@@ -260,7 +261,7 @@ if __name__ == '__main__':
-     script = None
-     if args.commands:
-         with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.sh') as script:
--            script.write('#!/usr/bin/bash\n\n')
-+            script.write('#!/bin/bash\n\n')
-             script.write(args.commands + '\n')
-         os.chmod(script.name, 0o744)
-         logging.info('Using temporary interestingness test: %s' % script.name)
-@@ -268,7 +269,8 @@ if __name__ == '__main__':
- 
-     test_manager = testing.TestManager(pass_statistic, args.interestingness_test, args.timeout,
-                                        args.save_temps, args.test_cases, args.n, args.no_cache, args.skip_key_off, args.shaddap,
--                                       args.die_on_pass_bug, args.print_diff, args.max_improvement, args.no_give_up, args.also_interesting)
-+                                       args.die_on_pass_bug, args.print_diff, args.max_improvement, args.no_give_up, args.also_interesting,
-+                                       args.start_with_pass)
- 
-     reducer = CVise(test_manager)
- 
-diff --git a/cvise/cvise.py b/cvise/cvise.py
-index 3f1da0b..5e4917b 100644
---- a/cvise/cvise.py
-+++ b/cvise/cvise.py
-@@ -122,7 +122,7 @@ class CVise:
- 
-         return pass_group
- 
--    def reduce(self, pass_group, skip_initial=False):
-+    def reduce(self, pass_group, skip_initial):
-         self._check_prerequisites(pass_group)
-         self.test_manager.check_sanity(True)
- 
-diff --git a/cvise/passes/clangbinarysearch.py b/cvise/passes/clangbinarysearch.py
-index 741a7da..ce6627f 100644
---- a/cvise/passes/clangbinarysearch.py
-+++ b/cvise/passes/clangbinarysearch.py
-@@ -51,9 +51,13 @@ class ClangBinarySearchPass(AbstractPass):
- 
-         try:
-             proc = subprocess.run(cmd, universal_newlines=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
--        except subprocess.SubprocessError:
-+        except subprocess.SubprocessError as e:
-+            logging.warning(f'clang_delta --query-instances failed: {e}')
-             return 0
- 
-+        if proc.returncode != 0:
-+            logging.warning(f'clang_delta --query-instances failed with exit code {proc.returncode}: {proc.stderr.strip()}')
-+
-         m = re.match('Available transformation instances: ([0-9]+)$', proc.stdout)
- 
-         if m is None:
-diff --git a/cvise/passes/lines.py b/cvise/passes/lines.py
-index 9bc7675..f326325 100644
---- a/cvise/passes/lines.py
-+++ b/cvise/passes/lines.py
-@@ -34,6 +34,7 @@ class LinesPass(AbstractPass):
-             try:
-                 check_sanity()
-             except InsaneTestCaseError:
-+
-                 shutil.move(backup.name, test_case)
-                 # if we are not the first lines pass, we should bail out
-                 if self.arg != '0':
-@@ -52,7 +53,7 @@ class LinesPass(AbstractPass):
-         if self.arg != 'None':
-             self.__format(test_case, check_sanity)
-             if self.bailout:
--                logging.info('Skipping pass as sanity check fails for topformflat output')
-+                logging.warning('Skipping pass as sanity check fails for topformflat output')
-                 return None
-         instances = self.__count_instances(test_case)
-         return BinaryState.create(instances)
-diff --git a/cvise/utils/testing.py b/cvise/utils/testing.py
-index ceb18da..f60c44a 100644
---- a/cvise/utils/testing.py
-+++ b/cvise/utils/testing.py
-@@ -130,12 +130,13 @@ class TestManager:
- 
-     def __init__(self, pass_statistic, test_script, timeout, save_temps, test_cases, parallel_tests,
-                  no_cache, skip_key_off, silent_pass_bug, die_on_pass_bug, print_diff, max_improvement,
--                 no_give_up, also_interesting):
-+                 no_give_up, also_interesting, start_with_pass):
-         self.test_script = os.path.abspath(test_script)
-         self.timeout = timeout
-         self.save_temps = save_temps
-         self.pass_statistic = pass_statistic
-         self.test_cases = set()
-+        self.test_cases_modes = {}
-         self.parallel_tests = parallel_tests
-         self.no_cache = no_cache
-         self.skip_key_off = skip_key_off
-@@ -145,10 +146,13 @@ class TestManager:
-         self.max_improvement = max_improvement
-         self.no_give_up = no_give_up
-         self.also_interesting = also_interesting
-+        self.start_with_pass = start_with_pass
- 
-         for test_case in test_cases:
-             self.check_file_permissions(test_case, [os.F_OK, os.R_OK, os.W_OK], InvalidTestCaseError)
--            self.test_cases.add(os.path.abspath(test_case))
-+            fullpath = os.path.abspath(test_case)
-+            self.test_cases.add(fullpath)
-+            self.test_cases_modes[fullpath] = os.stat(fullpath).st_mode
- 
-         self.orig_total_file_size = self.total_file_size
-         self.cache = {}
-@@ -165,6 +169,10 @@ class TestManager:
-         if not self.save_temps:
-             rmfolder(self.root)
- 
-+    def restore_mode(self):
-+        for test_case in self.test_cases:
-+            os.chmod(test_case, self.test_cases_modes[test_case])
-+
-     @classmethod
-     def is_valid_test(cls, test_script):
-         for mode in {os.F_OK, os.X_OK}:
-@@ -193,7 +201,7 @@ class TestManager:
-         lines = 0
-         for file in files:
-             with open(file) as f:
--                lines += len(f.readlines())
-+                lines += len([line for line in f.readlines() if line and not line.isspace()])
-         return lines
- 
-     def backup_test_cases(self):
-@@ -441,6 +449,12 @@ class TestManager:
-                     self.state = state
- 
-     def run_pass(self, pass_):
-+        if self.start_with_pass:
-+            if self.start_with_pass == str(pass_):
-+                self.start_with_pass = None
-+            else:
-+                return
-+
-         self.current_pass = pass_
-         self.futures = []
-         self.temporary_folders = {}
-@@ -509,6 +523,7 @@ class TestManager:
- 
-                     self.cache[pass_key][test_case_before_pass] = tmp_file.read()
- 
-+        self.restore_mode()
-         self.remove_root()
-         self.pass_statistic.stop(self.current_pass)
- 
-diff --git a/tests/test_cvise.py b/tests/test_cvise.py
-index 7982350..987ae2b 100644
---- a/tests/test_cvise.py
-+++ b/tests/test_cvise.py
-@@ -1,5 +1,6 @@
- import os
- import shutil
-+import stat
- import subprocess
- import unittest
- 
-@@ -11,9 +12,11 @@ class TestCvise(unittest.TestCase):
-         current = os.path.dirname(__file__)
-         binary = os.path.join(current, '../cvise.py')
-         shutil.copy(os.path.join(current, 'sources', testcase), '.')
-+        os.chmod(testcase, 0o644)
-         cmd = '%s %s %s' % (binary, testcase, arguments)
-         subprocess.check_output(cmd, shell=True, encoding='utf8')
-         assert open(testcase).read() == expected
-+        assert stat.filemode(os.stat(testcase).st_mode) == '-rw-r--r--'
- 
-     def test_simple_reduction(self):
-         self.check_cvise('blocksort-part.c', '-c "gcc -c blocksort-part.c && grep nextHi blocksort-part.c"', '#define nextHi')
diff -pruN 2.0.0-4/debian/patches/series 2.1.0-1/debian/patches/series
--- 2.0.0-4/debian/patches/series	2020-11-10 11:04:00.000000000 +0000
+++ 2.1.0-1/debian/patches/series	2021-01-12 18:21:35.000000000 +0000
@@ -1 +1 @@
-git-updates.diff
+# git-updates.diff
diff -pruN 2.0.0-4/Docker/Dockerfile-fedora33-llvm11 2.1.0-1/Docker/Dockerfile-fedora33-llvm11
--- 2.0.0-4/Docker/Dockerfile-fedora33-llvm11	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/Docker/Dockerfile-fedora33-llvm11	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-FROM fedora:33
-
-RUN dnf install -y python3-pip python3-pytest python3-psutil llvm-devel clang-devel cmake make flex unifdef \
-        python3-pytest-flake8 \
-        python3-flake8 \
-        python3-flake8-import-order
-RUN pip3 install Pebble
-
-WORKDIR /usr/src/cvise
-VOLUME /usr/src/cvise
diff -pruN 2.0.0-4/Docker/Dockerfile-fedoradev-llvm11 2.1.0-1/Docker/Dockerfile-fedoradev-llvm11
--- 2.0.0-4/Docker/Dockerfile-fedoradev-llvm11	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/Docker/Dockerfile-fedoradev-llvm11	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-FROM fedora:rawhide
-
-RUN dnf install -y python3-pip python3-pytest python3-psutil llvm-devel clang-devel cmake make flex unifdef \
-        python3-pytest-flake8 \
-        python3-flake8 \
-        python3-flake8-import-order
-RUN pip3 install Pebble
-
-WORKDIR /usr/src/cvise
-VOLUME /usr/src/cvise
diff -pruN 2.0.0-4/Docker/Dockerfile-opensusetw-llvm10 2.1.0-1/Docker/Dockerfile-opensusetw-llvm10
--- 2.0.0-4/Docker/Dockerfile-opensusetw-llvm10	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/Docker/Dockerfile-opensusetw-llvm10	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-FROM opensuse/tumbleweed
-
-RUN zypper -n install \
-        binutils clang10-devel cmake flex gcc-c++ llvm10-devel python3-Pebble python3-pytest unifdef python3-pip python3-psutil sqlite-devel git python3 \
-        python3-pytest-flake8 \
-        python3-flake8 \
-        python3-flake8-builtins \
-        python3-flake8-bugbear \
-        python3-flake8-comprehensions\
-        python3-flake8-import-order \
-        python3-flake8-quotes
-RUN pip install codecov pytest-cov
-ENV LSAN_OPTIONS="detect_leaks=0"
-
-WORKDIR /usr/src/cvise
-VOLUME /usr/src/cvise
diff -pruN 2.0.0-4/Docker/Dockerfile-opensusetw-llvm11 2.1.0-1/Docker/Dockerfile-opensusetw-llvm11
--- 2.0.0-4/Docker/Dockerfile-opensusetw-llvm11	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/Docker/Dockerfile-opensusetw-llvm11	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-FROM opensuse/tumbleweed
-
-RUN zypper -n install \
-        binutils clang11-devel cmake flex gcc-c++ llvm11-devel python3-Pebble python3-pytest unifdef python3-pip python3-psutil sqlite-devel git python3 \
-        python3-pytest-flake8 \
-        python3-flake8 \
-        python3-flake8-builtins \
-        python3-flake8-bugbear \
-        python3-flake8-comprehensions\
-        python3-flake8-import-order \
-        python3-flake8-quotes
-RUN pip install codecov pytest-cov
-ENV LSAN_OPTIONS="detect_leaks=0"
-
-WORKDIR /usr/src/cvise
-VOLUME /usr/src/cvise
diff -pruN 2.0.0-4/Docker/Dockerfile-opensusetw-llvm9 2.1.0-1/Docker/Dockerfile-opensusetw-llvm9
--- 2.0.0-4/Docker/Dockerfile-opensusetw-llvm9	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/Docker/Dockerfile-opensusetw-llvm9	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-FROM opensuse/tumbleweed
-
-RUN zypper -n install \
-        binutils clang9-devel cmake flex gcc-c++ llvm9-devel python3-Pebble python3-pytest python3-psutil unifdef \
-        python3-pytest-flake8 \
-        python3-flake8 \
-        python3-flake8-builtins \
-        python3-flake8-bugbear \
-        python3-flake8-comprehensions\
-        python3-flake8-import-order \
-        python3-flake8-quotes
-ENV LSAN_OPTIONS="detect_leaks=0"
-
-WORKDIR /usr/src/cvise
-VOLUME /usr/src/cvise
diff -pruN 2.0.0-4/.github/workflows/build.yml 2.1.0-1/.github/workflows/build.yml
--- 2.0.0-4/.github/workflows/build.yml	1970-01-01 00:00:00.000000000 +0000
+++ 2.1.0-1/.github/workflows/build.yml	2021-01-11 10:52:13.000000000 +0000
@@ -0,0 +1,65 @@
+name: Build
+
+on:
+  push:
+    branches: [ master ]
+  pull_request:
+    branches: [ master ]
+
+jobs:
+  build_and_test:
+    runs-on: ubuntu-latest
+
+    strategy:
+      matrix:
+        llvm: [9, 10, 11]
+        build-type: [DEBUG]
+        docker: [opensuse/tumbleweed]
+        include:
+          - llvm: 11
+            build-type: ASAN
+            docker: opensuse/tumbleweed
+          - llvm: 11
+            build-type: UBSAN
+            docker: opensuse/tumbleweed
+          - llvm: 11
+            build-type: COVERAGE
+            docker: opensuse/tumbleweed
+          - llvm: 9
+            build-type: DEBUG
+            docker: opensuse/leap
+
+    container: ${{ matrix.docker }}
+
+    steps:
+    - run: zypper -n install
+        binutils clang${{ matrix.llvm }}-devel cmake flex gcc-c++ llvm${{ matrix.llvm }}-devel python3-Pebble python3-pytest unifdef python3-psutil curl git
+        python3-pytest-flake8
+        python3-flake8
+        python3-flake8-builtins
+        python3-flake8-bugbear
+        python3-flake8-import-order
+        python3-flake8-quotes
+    - run: zypper -n install python3-pip python3-flake8-comprehensions python3 sqlite-devel
+      if: matrix.docker == 'opensuse/tumbleweed'
+    - run: pip install codecov pytest-cov
+      if: matrix.docker == 'opensuse/tumbleweed'
+    - uses: actions/checkout@v2
+    - run: nproc
+    - name: build
+      run: |
+            mkdir objdir
+            cd objdir
+            cmake .. -DCMAKE_BUILD_TYPE=${{ matrix.build-type }}
+            make -j`nproc` VERBOSE=1
+    - name: test
+      run: |
+            cd objdir
+            pytest
+      if: matrix.build-type != 'COVERAGE'
+    - name: test with coverage
+      run: |
+            cd objdir
+            pytest --cov=./
+            codecov
+      if: matrix.build-type == 'COVERAGE'
diff -pruN 2.0.0-4/README.md 2.1.0-1/README.md
--- 2.0.0-4/README.md	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/README.md	2021-01-11 10:52:13.000000000 +0000
@@ -1,7 +1,7 @@
 # C-Vise
 
 [![OBS master](https://build.opensuse.org/assets/favicon-ac48595b97f38c2425d7ea77739a63d771fcda9f73cc8c474b66461c0836fc2a.ico)](https://build.opensuse.org/package/show/home:marxin:cvise-github/cvise)
-[![Travis Build Status](https://travis-ci.com/marxin/cvise.svg?branch=master)](https://travis-ci.com/marxin/cvise)
+![GitHub Actions](https://github.com/marxin/cvise/workflows/Build/badge.svg)
 [![Total alerts](https://img.shields.io/lgtm/alerts/g/marxin/cvise.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/marxin/cvise/alerts/)
 [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/marxin/cvise.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/marxin/cvise/context:python)
 [![Language grade: C/C++](https://img.shields.io/lgtm/grade/cpp/g/marxin/cvise.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/marxin/cvise/context:cpp)
diff -pruN 2.0.0-4/tests/test_cvise.py 2.1.0-1/tests/test_cvise.py
--- 2.0.0-4/tests/test_cvise.py	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/tests/test_cvise.py	2021-01-11 10:52:13.000000000 +0000
@@ -1,5 +1,6 @@
 import os
 import shutil
+import stat
 import subprocess
 import unittest
 
@@ -11,9 +12,11 @@ class TestCvise(unittest.TestCase):
         current = os.path.dirname(__file__)
         binary = os.path.join(current, '../cvise.py')
         shutil.copy(os.path.join(current, 'sources', testcase), '.')
+        os.chmod(testcase, 0o644)
         cmd = '%s %s %s' % (binary, testcase, arguments)
         subprocess.check_output(cmd, shell=True, encoding='utf8')
         assert open(testcase).read() == expected
+        assert stat.filemode(os.stat(testcase).st_mode) == '-rw-r--r--'
 
     def test_simple_reduction(self):
         self.check_cvise('blocksort-part.c', '-c "gcc -c blocksort-part.c && grep nextHi blocksort-part.c"', '#define nextHi')
diff -pruN 2.0.0-4/.travis.yml 2.1.0-1/.travis.yml
--- 2.0.0-4/.travis.yml	2020-11-15 09:49:05.000000000 +0000
+++ 2.1.0-1/.travis.yml	1970-01-01 00:00:00.000000000 +0000
@@ -1,74 +0,0 @@
-##
-## Copyright (c) 2015, 2016, 2017, 2018, 2019 The University of Utah
-## Copyright (c) 2015 Tamir Duberstein
-## All rights reserved.
-##
-## This file is distributed under the University of Illinois Open Source
-## License.  See the file COPYING for details.
-##
-
-###############################################################################
-
-sudo: required
-dist: bionic
-language: cpp
-
-stages:
-  - build
-
-# podman is currently not in Ubuntu
-addons:
-  apt:
-    update: true
-    sources:
-      - sourceline: "ppa:projectatomic/ppa"
-    packages:
-      - podman slirp4netns
-
-matrix:
-  - include:
-    - name: COVERAGE build (LLVM 11)
-      stage: build
-      env:
-        - BUILD_TYPE=COVERAGE
-        - DIST=opensusetw-llvm11
-
-    - name: UBSAN build (LLVM 11)
-      stage: build
-      env:
-        - BUILD_TYPE=UBSAN
-        - DIST=opensusetw-llvm11
-
-    - name: ASAN build (LLVM 11)
-      stage: build
-      env:
-        - BUILD_TYPE=ASAN
-        - DIST=opensusetw-llvm11
-
-    - name: Fedora 33 DEBUG build (LLVM 11)
-      stage: build
-      env:
-        - BUILD_TYPE=DEBUG
-        - DIST=fedora33-llvm11
-
-    - name: Fedora dev DEBUG build (LLVM 11)
-      stage: build
-      env:
-        - BUILD_TYPE=DEBUG
-        - DIST=fedoradev-llvm11
-
-before_install:
-  # podman needs a basic register set up (packaging bug in the ppa)
-  - sudo mkdir -p /etc/containers
-  - echo -e "[registries.search]\nregistries = ['docker.io']" | sudo tee /etc/containers/registries.conf
-  # we need to register travis to allow subuid/gid for the rootless execution
-  - echo "travis:110000:65535" | sudo tee /etc/subuid
-  - echo "travis:110000:65535" | sudo tee /etc/subgid
-
-script:
-  - podman build -t $DIST -f Docker/Dockerfile-$DIST .
-  - podman run -v $(pwd):/usr/src/cvise $DIST ./build_and_test.sh $BUILD_TYPE
-
-###############################################################################
-
-## End of file.
